import { onMounted, onUnmounted, defineComponent, ref, watchEffect } from 'vue';
import { useRoute } from 'vue-router';
import {
  useCommonStore,
  useDaHuaStore,
  useIncidentStore,
  useMainStore,
  useMarkerStore,
} from '@/store';
import IncidentInfoCard from './IncidentInfoCard';
import CommandChainCard from './CommandChainCard';
import EmergencyLinkageCard from './EmergencyLinkageCard';
import IncidentPlanCard from './IncidentPlanCard';
import LiveMonitoringCard from './LiveMonitoringCard';
import ExecutionLogCard from './ExecutionLogCard';
import LiveVideoCard from './LiveVideoCard';
import './index.scss';
import { watch } from 'fs';
import { isEmpty } from 'lodash';
import isString from 'lodash/isString';
import { NeedsReadUser, NeedsReadUserName } from '@/api/common';
import { BaseReg } from '@/constants/constants';

export default defineComponent({
  name: 'IncidentDetail',
  provide: {},
  setup() {
    const store = useIncidentStore();
    const commonStore = useCommonStore();
    const mainStore = useMainStore();
    const markerStore = useMarkerStore();
    const daHuaStore = useDaHuaStore();
    const route = useRoute();

    const liveVideoRef = ref<HTMLElement>();

    watchEffect(() => {
      const messageIDs =
        store.incidentDetail?.process
          ?.map((item) => (item.des?.match(BaseReg) ? item.id : null))
          .filter(isString) ?? [];
      if (messageIDs.length > 0) {
        Promise.all(
          messageIDs.map((id) =>
            mainStore.getMessage({
              msType: '2',
              msSource: '1',
              msNo: id,
            }),
          ),
        ).then((rows) => {
          rows.forEach((message) => {
            if (message?.[0]) {
              const m = message[0];
              const idx = store.incidentDetail.process?.findIndex(
                (p) => p.id === m.msNo,
              );
              if (idx && idx >= 0) {
                // @ts-ignore
                store.incidentDetail.process[idx].des =
                  // @ts-ignore
                  (store.incidentDetail.process[idx].des.replace(
                    /\+\+\+\+/g,
                    '',
                  ) ?? '') +
                  '>>>>' +
                  NeedsReadUserName.map((user) => user).join(',');
                // (m.messageReadInfoList
                //   ?.map((user) =>
                //     user.readState === '0' ? user.userId : null,
                //   )
                //   .filter(isString)) ?? '' ;
              }
            }
          });
        });
      }
    });

    onMounted(async () => {
      commonStore.getGlobalDict('zhdd_incident_type');
      commonStore.getGlobalDict('zhdd_incident_source');
      commonStore.getGlobalDict('zhdd_org_upload');
      commonStore.getGlobalDict('zhdd_incident_level');
      liveVideoRef.value?.addEventListener('click', (el: MouseEvent) => {
        if (el.target && liveVideoRef.value?.contains(el.target as Node)) {
        }
      });
    });
    onUnmounted(() => {
      store.incidentDetail = {};
      markerStore.currentIncident = {};
      markerStore.livevideovisible = false;
      markerStore.livevideos = [];
    });

    return () => (
      <>
        <div class="incident-detail-page-container">
          {!markerStore.livevideovisible && (
            <div class="detail-left">
              <IncidentInfoCard />
              <CommandChainCard />
              <IncidentPlanCard />
              <EmergencyLinkageCard />
            </div>
          )}

          {!daHuaStore.dahuaUserVisible && (
            <div class="detail-right">
              <ExecutionLogCard />
              <LiveMonitoringCard />
            </div>
          )}
        </div>
        {/*大华 相关的通讯录可以放这里*/}
        {/*{daHuaStore.dahuaUserVisible && (*/}
        {/*  <div ref={liveVideoRef} class="live-video-container-left right">*/}
        {/*    <div class="live-video-container">*/}
        {/*      <LiveVideoCard />*/}
        {/*      <div*/}
        {/*        class="live-video-close"*/}
        {/*        onClick={() => (daHuaStore.dahuaUserVisible = false)}*/}
        {/*      />*/}
        {/*    </div>*/}
        {/*  </div>*/}
        {/*)}*/}

        {markerStore.livevideovisible && (
          <div ref={liveVideoRef} class="live-video-container-left">
            <div class="live-video-container">
              <LiveVideoCard />
              <div
                class="live-video-close"
                onClick={() => (markerStore.livevideovisible = false)}
              />
            </div>
          </div>
        )}
      </>
    );
  },
});
